# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3election.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2
from etcetra.grpc_api import rpc_pb2 as rpc__pb2
from etcetra.grpc_api import kv_pb2 as kv__pb2
from etcetra.grpc_api import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10v3election.proto\x12\x0cv3electionpb\x1a\ngogo.proto\x1a\trpc.proto\x1a\x08kv.proto\x1a\x11\x61nnotations.proto\"=\n\x0f\x43\x61mpaignRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\r\n\x05lease\x18\x02 \x01(\x03\x12\r\n\x05value\x18\x03 \x01(\x0c\"i\n\x10\x43\x61mpaignResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\'\n\x06leader\x18\x02 \x01(\x0b\x32\x17.v3electionpb.LeaderKey\"B\n\tLeaderKey\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0b\n\x03rev\x18\x03 \x01(\x03\x12\r\n\x05lease\x18\x04 \x01(\x03\"\x1d\n\rLeaderRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c\"\\\n\x0eLeaderResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x1c\n\x02kv\x18\x02 \x01(\x0b\x32\x10.mvccpb.KeyValue\"8\n\rResignRequest\x12\'\n\x06leader\x18\x01 \x01(\x0b\x32\x17.v3electionpb.LeaderKey\">\n\x0eResignResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"I\n\x0fProclaimRequest\x12\'\n\x06leader\x18\x01 \x01(\x0b\x32\x17.v3electionpb.LeaderKey\x12\r\n\x05value\x18\x02 \x01(\x0c\"@\n\x10ProclaimResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader2\x97\x04\n\x08\x45lection\x12k\n\x08\x43\x61mpaign\x12\x1d.v3electionpb.CampaignRequest\x1a\x1e.v3electionpb.CampaignResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/election/campaign:\x01*\x12k\n\x08Proclaim\x12\x1d.v3electionpb.ProclaimRequest\x1a\x1e.v3electionpb.ProclaimResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/election/proclaim:\x01*\x12\x63\n\x06Leader\x12\x1b.v3electionpb.LeaderRequest\x1a\x1c.v3electionpb.LeaderResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/election/leader:\x01*\x12g\n\x07Observe\x12\x1b.v3electionpb.LeaderRequest\x1a\x1c.v3electionpb.LeaderResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/election/observe:\x01*0\x01\x12\x63\n\x06Resign\x12\x1b.v3electionpb.ResignRequest\x1a\x1c.v3electionpb.ResignResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/election/resign:\x01*B\x08\xc8\xe2\x1e\x01\xd0\xe2\x1e\x01\x62\x06proto3')



_CAMPAIGNREQUEST = DESCRIPTOR.message_types_by_name['CampaignRequest']
_CAMPAIGNRESPONSE = DESCRIPTOR.message_types_by_name['CampaignResponse']
_LEADERKEY = DESCRIPTOR.message_types_by_name['LeaderKey']
_LEADERREQUEST = DESCRIPTOR.message_types_by_name['LeaderRequest']
_LEADERRESPONSE = DESCRIPTOR.message_types_by_name['LeaderResponse']
_RESIGNREQUEST = DESCRIPTOR.message_types_by_name['ResignRequest']
_RESIGNRESPONSE = DESCRIPTOR.message_types_by_name['ResignResponse']
_PROCLAIMREQUEST = DESCRIPTOR.message_types_by_name['ProclaimRequest']
_PROCLAIMRESPONSE = DESCRIPTOR.message_types_by_name['ProclaimResponse']
CampaignRequest = _reflection.GeneratedProtocolMessageType('CampaignRequest', (_message.Message,), {
  'DESCRIPTOR' : _CAMPAIGNREQUEST,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.CampaignRequest)
  })
_sym_db.RegisterMessage(CampaignRequest)

CampaignResponse = _reflection.GeneratedProtocolMessageType('CampaignResponse', (_message.Message,), {
  'DESCRIPTOR' : _CAMPAIGNRESPONSE,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.CampaignResponse)
  })
_sym_db.RegisterMessage(CampaignResponse)

LeaderKey = _reflection.GeneratedProtocolMessageType('LeaderKey', (_message.Message,), {
  'DESCRIPTOR' : _LEADERKEY,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.LeaderKey)
  })
_sym_db.RegisterMessage(LeaderKey)

LeaderRequest = _reflection.GeneratedProtocolMessageType('LeaderRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEADERREQUEST,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.LeaderRequest)
  })
_sym_db.RegisterMessage(LeaderRequest)

LeaderResponse = _reflection.GeneratedProtocolMessageType('LeaderResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEADERRESPONSE,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.LeaderResponse)
  })
_sym_db.RegisterMessage(LeaderResponse)

ResignRequest = _reflection.GeneratedProtocolMessageType('ResignRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESIGNREQUEST,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.ResignRequest)
  })
_sym_db.RegisterMessage(ResignRequest)

ResignResponse = _reflection.GeneratedProtocolMessageType('ResignResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESIGNRESPONSE,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.ResignResponse)
  })
_sym_db.RegisterMessage(ResignResponse)

ProclaimRequest = _reflection.GeneratedProtocolMessageType('ProclaimRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCLAIMREQUEST,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.ProclaimRequest)
  })
_sym_db.RegisterMessage(ProclaimRequest)

ProclaimResponse = _reflection.GeneratedProtocolMessageType('ProclaimResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCLAIMRESPONSE,
  '__module__' : 'v3election_pb2'
  # @@protoc_insertion_point(class_scope:v3electionpb.ProclaimResponse)
  })
_sym_db.RegisterMessage(ProclaimResponse)

_ELECTION = DESCRIPTOR.services_by_name['Election']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\320\342\036\001'
  _ELECTION.methods_by_name['Campaign']._options = None
  _ELECTION.methods_by_name['Campaign']._serialized_options = b'\202\323\344\223\002\032\"\025/v3/election/campaign:\001*'
  _ELECTION.methods_by_name['Proclaim']._options = None
  _ELECTION.methods_by_name['Proclaim']._serialized_options = b'\202\323\344\223\002\032\"\025/v3/election/proclaim:\001*'
  _ELECTION.methods_by_name['Leader']._options = None
  _ELECTION.methods_by_name['Leader']._serialized_options = b'\202\323\344\223\002\030\"\023/v3/election/leader:\001*'
  _ELECTION.methods_by_name['Observe']._options = None
  _ELECTION.methods_by_name['Observe']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/election/observe:\001*'
  _ELECTION.methods_by_name['Resign']._options = None
  _ELECTION.methods_by_name['Resign']._serialized_options = b'\202\323\344\223\002\030\"\023/v3/election/resign:\001*'
  _CAMPAIGNREQUEST._serialized_start=86
  _CAMPAIGNREQUEST._serialized_end=147
  _CAMPAIGNRESPONSE._serialized_start=149
  _CAMPAIGNRESPONSE._serialized_end=254
  _LEADERKEY._serialized_start=256
  _LEADERKEY._serialized_end=322
  _LEADERREQUEST._serialized_start=324
  _LEADERREQUEST._serialized_end=353
  _LEADERRESPONSE._serialized_start=355
  _LEADERRESPONSE._serialized_end=447
  _RESIGNREQUEST._serialized_start=449
  _RESIGNREQUEST._serialized_end=505
  _RESIGNRESPONSE._serialized_start=507
  _RESIGNRESPONSE._serialized_end=569
  _PROCLAIMREQUEST._serialized_start=571
  _PROCLAIMREQUEST._serialized_end=644
  _PROCLAIMRESPONSE._serialized_start=646
  _PROCLAIMRESPONSE._serialized_end=710
  _ELECTION._serialized_start=713
  _ELECTION._serialized_end=1248
# @@protoc_insertion_point(module_scope)
